@@ -16,15 +16,14 @@ class HyperChat:
     def run(self):
         self.chat_manager = ChatManager(self, self.host, self.token, self.api.lista_canales(), ssl_active=self.ssl)
 
-    def route(self, command):
+    def handler(self, commands: list):
         def decorator(f):
             @wraps(f)
-            def wrapper(*args, **kwargs):
-                f(args, kwargs)
-
-            self.rutas[command] = wrapper
+            def wrapper(*args):
+                f(*args)
+            for comm in commands:
+                self.rutas[comm] = wrapper
             return wrapper
-
         return decorator
 
     def send(self, request, mensaje):
