@@ -70,9 +70,9 @@ class Chat:
             
         if mensaje.get('message').startswith('/'):
             command = mensaje.get('message')[1:].split(" ")[0]
-            if command in self.hyper_chat.rutas:
-                func = self.hyper_chat.rutas[command]
-                func(mensaje)
+            if command in self.hyper_chat.rutas.keys():
+                if f := self.hyper_chat.rutas.get(command, None):
+                    f(mensaje)
 
     def __on_close(self, ws, close_status_code, close_msg):
         self.sock_connected = False
